@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA 02110-1335, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -118,6 +117,7 @@ get_missing_executables (const gchar *ppd_file_name)
         GHashTable *executables = NULL;
         GDBusProxy *proxy;
         GVariant   *output;
+        GVariant   *array;
         GError     *error = NULL;
         gint        i;
 
@@ -149,23 +149,17 @@ get_missing_executables (const gchar *ppd_file_name)
                                          &error);
 
         if (output && g_variant_n_children (output) == 1) {
-                GVariant *array = g_variant_get_child_value (output, 0);
+                array = g_variant_get_child_value (output, 0);
                 if (array) {
                         executables = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                              g_free, NULL);
                         for (i = 0; i < g_variant_n_children (array); i++) {
-                                GVariant *child_value = g_variant_get_child_value (array, i);
                                 g_hash_table_insert (executables,
                                                      g_strdup (g_variant_get_string (
-                                                       child_value,
+                                                       g_variant_get_child_value (array, i),
                                                        NULL)),
                                                      NULL);
-                                if (child_value) {
-                                        g_variant_unref (child_value);
-                                }
                         }
-
-                        g_variant_unref (array);
                 }
         }
 
@@ -312,6 +306,8 @@ get_best_ppd (gchar *device_id,
 {
         GDBusProxy  *proxy;
         GVariant    *output;
+        GVariant    *array;
+        GVariant    *tuple;
         GError      *error = NULL;
         gchar       *ppd_name = NULL;
         gint         i, j;
@@ -349,37 +345,20 @@ get_best_ppd (gchar *device_id,
                                          &error);
 
         if (output && g_variant_n_children (output) >= 1) {
-                GVariant *array = g_variant_get_child_value (output, 0);
-                if (array) {
-                        for (j = 0; j < G_N_ELEMENTS (match_levels) && ppd_name == NULL; j++) {
+                array = g_variant_get_child_value (output, 0);
+                if (array)
+                        for (j = 0; j < G_N_ELEMENTS (match_levels) && ppd_name == NULL; j++)
                                 for (i = 0; i < g_variant_n_children (array) && ppd_name == NULL; i++) {
-                                        GVariant *tuple = g_variant_get_child_value (array, i);
+                                        tuple = g_variant_get_child_value (array, i);
                                         if (tuple && g_variant_n_children (tuple) == 2) {
-                                                GVariant *child_value_1 = g_variant_get_child_value (tuple, 1);
-                                                if (g_strcmp0 (g_variant_get_string (child_value_1, NULL),
-                                                        match_levels[j]) == 0) {
-                                                        GVariant *child_value_0 = g_variant_get_child_value (tuple, 0);
+                                                if (g_strcmp0 (g_variant_get_string (
+                                                                   g_variant_get_child_value (tuple, 1),
+                                                                   NULL), match_levels[j]) == 0)
                                                         ppd_name = g_strdup (g_variant_get_string (
-                                                                                 child_value_0,
+                                                                                 g_variant_get_child_value (tuple, 0),
                                                                                  NULL));
-                                                        if (child_value_0) {
-                                                                g_variant_unref (child_value_0);
-                                                        }
-                                                }
-
-                                                if (child_value_1) {
-                                                        g_variant_unref (child_value_1);
-                                                }
-                                        }
-
-                                        if (tuple) {
-                                                g_variant_unref (tuple);
                                         }
                                 }
-                        }
-
-                        g_variant_unref (array);
-                }
         }
 
         if (output) {
@@ -503,9 +482,9 @@ add_printer (gchar *printer_name,
         output = g_dbus_proxy_call_sync (proxy,
                                          "PrinterAdd",
                                          g_variant_new ("(sssss)",
-                                                        printer_name ? printer_name : "",
-                                                        device_uri ? device_uri : "",
-                                                        ppd_name ? ppd_name : "",
+                                                        printer_name,
+                                                        device_uri,
+                                                        ppd_name,
                                                         info ? info : "",
                                                         location ? location : ""),
                                          G_DBUS_CALL_FLAGS_NONE,
@@ -754,7 +733,7 @@ printer_autoconfigure (gchar *printer_name)
                                                         ("Automatic configuration"));
                 if (response) {
                         if (ippGetState (response) == IPP_ERROR)
-                                g_warning ("An error has occurred during automatic configuration of new printer.");
+                                g_warning ("An error has occured during automatic configuration of new printer.");
                         ippDelete (response);
                 }
         }
@@ -762,23 +741,23 @@ printer_autoconfigure (gchar *printer_name)
         g_free (commands_lowercase);
 }
 
-/* Return default media size for current locale */
+/* Returns default page size for current locale */
 static const gchar *
-get_paper_size_from_locale ()
+get_page_size_from_locale (void)
 {
   if (g_str_equal (gtk_paper_size_get_default (), GTK_PAPER_NAME_LETTER))
-    return "na-letter";
+    return "Letter";
   else
-    return "iso-a4";
+    return "A4";
 }
 
 static void
 set_default_paper_size (const gchar *printer_name,
                         const gchar *ppd_file_name)
 {
-        GDBusProxy  *proxy;
-        GVariant    *output;
-        GError      *error = NULL;
+        GDBusProxy      *proxy;
+        GVariant        *output;
+        GError          *error = NULL;
         GVariantBuilder *builder;
 
         proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
@@ -800,13 +779,13 @@ set_default_paper_size (const gchar *printer_name,
          * FIXME: Handle more than A4 and Letter:
          * https://bugzilla.gnome.org/show_bug.cgi?id=660769 */
         builder = g_variant_builder_new (G_VARIANT_TYPE ("as"));
-        g_variant_builder_add (builder, "s", get_paper_size_from_locale ());
+        g_variant_builder_add (builder, "s", get_page_size_from_locale ());
 
         output = g_dbus_proxy_call_sync (proxy,
                                          "PrinterAddOption",
                                          g_variant_new ("(ssas)",
                                                         printer_name ? printer_name : "",
-                                                        "media",
+                                                        "PageSize",
                                                         builder),
                                          G_DBUS_CALL_FLAGS_NONE,
                                          DBUS_TIMEOUT,
@@ -1322,8 +1301,6 @@ main (int argc, char *argv[])
   npn_owner_id = 0;
   pdi_owner_id = 0;
 
-  g_type_init ();
-
   notify_init ("cinnamon-settings-daemon-printer");
 
   npn_introspection_data =
